@@ -10,7 +10,7 @@ type t =
   ; fork_each_benchmark : bool
   ; thin_overhead : int option
   }
-[@@deriving fields, sexp]
+[@@deriving fields ~getters, sexp]
 
 val create
   :  ?verbosity:Verbosity.t
