@@ -19,17 +19,17 @@ module Basic_test = struct
     ; group_key : int option
     ; f : packed_f
     }
-  [@@deriving fields]
+  [@@deriving fields ~getters]
 
   let create_with_initialization
-        ~name
-        ?(test_name = "")
-        ?(file_name = "")
-        ?(module_name = "")
-        ?(group_key = None)
-        ?(arg = None)
-        ~key
-        f
+    ~name
+    ?(test_name = "")
+    ?(file_name = "")
+    ?(module_name = "")
+    ?(group_key = None)
+    ?(arg = None)
+    ~key
+    f
     =
     { name
     ; test_name
@@ -56,15 +56,15 @@ type t =
   ; module_name : string
   ; tests : Basic_test.t list
   }
-[@@deriving fields]
+[@@deriving fields ~getters]
 
 let create_with_initialization
-      ~name
-      ?(test_name = "")
-      ?(file_name = "")
-      ?(module_name = "")
-      ?(key = 0)
-      bm
+  ~name
+  ?(test_name = "")
+  ?(file_name = "")
+  ?(module_name = "")
+  ?(key = 0)
+  bm
   =
   { name
   ; test_name
@@ -88,13 +88,13 @@ let create ~name ?test_name ?file_name ?module_name ?key bm =
 ;;
 
 let create_parameterised
-      ~name
-      ?(test_name = "")
-      ?(file_name = "")
-      ?(module_name = "")
-      ~args
-      ?(key = 0)
-      bm
+  ~name
+  ?(test_name = "")
+  ?(file_name = "")
+  ?(module_name = "")
+  ~args
+  ?(key = 0)
+  bm
   =
   { name
   ; test_name
