@@ -10,12 +10,11 @@ module Variable = Variable
 module Measurement = Measurement
 module Analysis_config = Analysis_config
 module Analysis_result = Analysis_result
-
 include Core_bench_internals.Bench
 
 let measure = Bench.measure ~measure_with:Benchmark.measure_all
 
-let display ?libname ?(display_config = Display_config.create ()) =
+let display ?libname ?(display_config = Display_config.default) =
   My_display.display ?libname ~display_config
 ;;
 
