@@ -30,6 +30,7 @@ let measure =
     let total_runs = ref 0 in
     (* get the old Gc settings *)
     let old_gc = Gc.get () in
+    stabilize_gc ();
     (* THE MAIN TEST LOOP *)
     let init_t1 = Time_float.now () in
     let quota = RC.quota run_config in
@@ -50,13 +51,14 @@ let measure =
          When benchmarking functions that do not allocate any memory, this early noise is
          the only significant input. In these cases, these spurious early collections will
          give the allocation stats (major and promoted words) a slight negative value. *)
-      if RC.stabilize_gc_between_runs run_config || current_runs = 0 then stabilize_gc ();
+      if RC.stabilize_gc_between_runs run_config && current_runs <> 0 then stabilize_gc ();
       (* make any Gc changes required. *)
       if RC.no_compactions run_config
       then Gc.set { (Gc.get ()) with Gc.Control.max_overhead = 1_000_000 };
       (* pre-run measurements *)
+      let gc1_minor_words, gc1_promoted_words, gc1_major_words = Gc.counters () in
       let gc1 = Gc.quick_stat () in
-      let t1 = Time_float.now () in
+      let t1 = Time_now.nanosecond_counter_for_timing () in
       (* MEASURE A SINGLE SAMPLE *)
       for _ = 1 to current_runs do
         ignore (f () : (* existential type from GADT *) _)
@@ -64,7 +66,8 @@ let measure =
       (* END OF MEASUREMENT *)
 
       (* post-run measurements *)
-      let t2 = Time_float.now () in
+      let t2 = Time_now.nanosecond_counter_for_timing () in
+      let gc2_minor_words, gc2_promoted_words, gc2_major_words = Gc.counters () in
       let gc2 = Gc.quick_stat () in
       total_runs := !total_runs + current_runs;
       (* reset the old Gc now that we are done with measurements *)
@@ -73,22 +76,18 @@ let measure =
       let s = results.(current_index) in
       s.M.runs <- current_runs;
       s.M.cycles <- Int63.zero;
-      s.M.nanos
-      <- Float.int63_round_down_exn (Time_float.Span.to_ns (Time_float.diff t2 t1));
+      s.M.nanos <- Int63.(t2 - t1);
       s.M.minor_allocated
-      <- Float.iround_towards_zero_exn
-           (gc2.Gc.Stat.minor_words -. gc1.Gc.Stat.minor_words);
+        <- Float.iround_towards_zero_exn (gc2_minor_words -. gc1_minor_words);
       s.M.major_allocated
-      <- Float.iround_towards_zero_exn
-           (gc2.Gc.Stat.major_words -. gc1.Gc.Stat.major_words);
+        <- Float.iround_towards_zero_exn (gc2_major_words -. gc1_major_words);
       s.M.promoted
-      <- Float.iround_towards_zero_exn
-           (gc2.Gc.Stat.promoted_words -. gc1.Gc.Stat.promoted_words);
+        <- Float.iround_towards_zero_exn (gc2_promoted_words -. gc1_promoted_words);
       s.M.compactions <- gc2.Gc.Stat.compactions - gc1.Gc.Stat.compactions;
       s.M.major_collections
-      <- gc2.Gc.Stat.major_collections - gc1.Gc.Stat.major_collections;
+        <- gc2.Gc.Stat.major_collections - gc1.Gc.Stat.major_collections;
       s.M.minor_collections
-      <- gc2.Gc.Stat.minor_collections - gc1.Gc.Stat.minor_collections;
+        <- gc2.Gc.Stat.minor_collections - gc1.Gc.Stat.minor_collections;
       incr index;
       (* determine the next number of runs *)
       let next =
@@ -117,8 +116,7 @@ let measure =
         ~file_name:(Test.Basic_test.file_name test)
         ~module_name:(Test.Basic_test.module_name test)
         ~largest_run
-        ~sample_count:total_samples
-        ~samples:results
+        ~samples:(Array.sub results ~pos:0 ~len:total_samples)
     in
     Verbosity.print_high
       "%s: Total time taken %s (%d samples, max runs %d).\n%!"
@@ -133,7 +131,15 @@ let measure =
 
 (* Run multiple benchmarks and aggregate the results. If forking is enabled then this
    function will fork and run each benchmark in a new child process. *)
-let measure_all run_config tests =
+let measure_all ?postprocess run_config tests =
+  let postprocess =
+    match postprocess with
+    | None -> Fn.id
+    | Some postprocess ->
+      fun measurement ->
+        postprocess measurement;
+        measurement
+  in
   Random.self_init ();
   let module RC = Run_config in
   Verbosity.set_verbosity (RC.verbosity run_config);
@@ -151,5 +157,5 @@ let measure_all run_config tests =
        (Time_float.Span.to_string est_time)
        (List.length tests)
        (Time_float.Span.to_string span));
-  List.map tests ~f:(measure run_config)
+  List.map tests ~f:(fun test -> test |> measure run_config |> postprocess)
 ;;
